/*
 Copyright (C) Johan Ceuppens 2011-2013

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef _MATRIX_H_
#define _MATRIX_H_


#include<cstring>
#include<iostream>
#include<vector>

namespace cola
{
template <class I>
class matrix 
{

////typedef std::vector<I> row;

public:
	matrix(int nrows, int mcols);
	matrix(matrix const& s);

	void set(I data, int r, int c);

	int getnrows() { return _rows.size(); }
	int getncols() { return _rows[0].size(); }

public:
	std::vector<I> operator[](int index); 
	matrix& operator=(matrix const& s); 

protected:
	std::vector<std::vector<I> > _rows;
	
};
} //namespace cola
#endif
